Class: IsoDoc::Plateau::PresentationXMLConvert
- Inherits:
-
Jis::PresentationXMLConvert
- Object
- Jis::PresentationXMLConvert
- IsoDoc::Plateau::PresentationXMLConvert
- Includes:
- Init
- Defined in:
- lib/isodoc/plateau/presentation_xml_convert.rb
Instance Method Summary collapse
- #alt_i18n ⇒ Object
- #alt_i18n_init(i18nyaml) ⇒ Object
- #anchor_linkend(node, linkend) ⇒ Object
- #bibdata_i18n(bib) ⇒ Object
- #commentary_title_hdr(elem) ⇒ Object
- #date_translate(bibdata) ⇒ Object
- #date_translate1(date) ⇒ Object
-
#dl(docxml) ⇒ Object
Undo JIS encoding of figure and table dl as paragraphs.
- #fmt_origin_cite_full?(elem) ⇒ Boolean
- #i18n_init(lang, script, locale, i18nyaml = nil) ⇒ Object
-
#initialize(options) ⇒ PresentationXMLConvert
constructor
A new instance of PresentationXMLConvert.
- #listsource(elem, ancestor) ⇒ Object
- #middle_title(docxml) ⇒ Object
-
#ol_depth(node) ⇒ Object
revert to iso.
- #parasource(elem) ⇒ Object
- #preface_init_insert_pt(docxml) ⇒ Object
- #rearrange_clauses(docxml) ⇒ Object
- #revert_i18n ⇒ Object
- #revhistory(docxml) ⇒ Object
- #short_style_origin(docxml) ⇒ Object
- #source_join_delim(_elem) ⇒ Object
- #source_types(docxml) ⇒ Object
-
#table_key(node) ⇒ Object
Insert localised colon at start of dd in table and figure key, replacing JIS Word